.. :changelog:

History
-------

0.2.2 (2014-11-14)
---------------------

* Added customization options and callbacks to Xapo micro payment tool.

0.2.1 (2014-11-04)
---------------------

* Added xapo_api module, including the credit api v0 (this is about to change soon in the incoming v1 api).
* Introduced xapo_tool.PaymentType constants.

0.2.0 (2014-11-01)
---------------------

* Having a TPA is not longer mandatory to provide a micro payments widget. Parameters app_id and app_secret are now optional. 

0.0.1 (2014-10-18)
---------------------

* First release on PyPI.
* Includes:
    * iframe widget
    * div widget